<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="39"/>
        <source>Row</source>
        <translation>行</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="40"/>
        <source>Column</source>
        <translation>列</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="41"/>
        <source>Characters %1</source>
        <translation>字數 %1</translation>
    </message>
</context>
<context>
    <name>DDropdownMenu</name>
    <message>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="300"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="344"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="349"/>
        <source>None</source>
        <translation>無</translation>
    </message>
</context>
<context>
    <name>EditWrapper</name>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="201"/>
        <location filename="../src/editor/editwrapper.cpp" line="264"/>
        <location filename="../src/editor/editwrapper.cpp" line="321"/>
        <location filename="../src/editor/editwrapper.cpp" line="536"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="316"/>
        <source>Do you want to save this file?</source>
        <translation>您是否要保存此文件？</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="262"/>
        <location filename="../src/editor/editwrapper.cpp" line="319"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="259"/>
        <source>Encoding changed. Do you want to save the file now?</source>
        <translation>文件編碼已更改，是否先進行保存？</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="320"/>
        <source>Discard</source>
        <translation>不保存</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="445"/>
        <source>You do not have permission to save %1</source>
        <translation>您沒有權限保存%1</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="607"/>
        <source>File removed on the disk. Save it now?</source>
        <translation>磁盤中的原文件已被移除，是否另存？</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="612"/>
        <source>File has changed on disk. Reload?</source>
        <translation>磁盤中的原文件已被修改，是否重新載入？</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="634"/>
        <location filename="../src/widgets/bottombar.cpp" line="60"/>
        <source>INSERT</source>
        <translation>插入</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="637"/>
        <source>OVERWRITE</source>
        <translation>覆蓋</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="640"/>
        <source>R/O</source>
        <translation>只讀</translation>
    </message>
</context>
<context>
    <name>FindBar</name>
    <message>
        <location filename="../src/controls/findbar.cpp" line="40"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="44"/>
        <source>Previous</source>
        <translation>上一個</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="46"/>
        <source>Next</source>
        <translation>下一個</translation>
    </message>
</context>
<context>
    <name>JumpLineBar</name>
    <message>
        <location filename="../src/controls/jumplinebar.cpp" line="40"/>
        <source>Go to Line: </source>
        <translation>跳到行：</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="27"/>
        <source>Text Editor is a powerful tool for viewing and editing text files.</source>
        <translation>文本編輯器是一款用來查看和編輯文本文件的工具。</translation>
    </message>
    <message>
        <location filename="../src/editorapplication.cpp" line="38"/>
        <source>Text Editor</source>
        <translation>文本編輯器</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="35"/>
        <source>Text Editor</source>
        <translation>文本編輯器</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="203"/>
        <location filename="../src/editor/editwrapper.cpp" line="538"/>
        <location filename="../src/widgets/window.cpp" line="956"/>
        <location filename="../src/widgets/window.cpp" line="973"/>
        <location filename="../src/widgets/window.cpp" line="1064"/>
        <location filename="../src/widgets/window.cpp" line="1079"/>
        <source>Encoding</source>
        <translation>編碼</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="24"/>
        <source>Basic</source>
        <translation>基礎設置</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="25"/>
        <source>Font Style</source>
        <translation>字體樣式</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="26"/>
        <source>Font</source>
        <translation>字體</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="27"/>
        <source>Font Size</source>
        <translation>字號</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="28"/>
        <source>Shortcuts</source>
        <translation>快捷鍵</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="29"/>
        <location filename="../src/controls/settingsdialog.cpp" line="30"/>
        <source>Keymap</source>
        <translation>快捷鍵映射</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="31"/>
        <location filename="../src/controls/settingsdialog.cpp" line="107"/>
        <location filename="../src/widgets/window.cpp" line="1482"/>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="32"/>
        <source>New tab</source>
        <translation>新標籤頁</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="33"/>
        <source>New window</source>
        <translation>新窗口</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="34"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="35"/>
        <source>Save as</source>
        <translation>另存為</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="36"/>
        <source>Next tab</source>
        <translation>下一個標籤頁</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="37"/>
        <source>Previous tab</source>
        <translation>上一個標籤頁</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="38"/>
        <source>Close tab</source>
        <translation>關閉標籤頁</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="39"/>
        <source>Close other tabs</source>
        <translation>關閉其他標籤頁</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="40"/>
        <source>Restore tab</source>
        <translation>恢復標籤頁</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="41"/>
        <source>Open file</source>
        <translation>打開文件</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="42"/>
        <source>Increment font size</source>
        <translation>放大字號</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="43"/>
        <source>Decrement font size</source>
        <translation>縮小字號</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="44"/>
        <source>Reset font size</source>
        <translation>還原字號</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="45"/>
        <source>Help</source>
        <translation>幫助</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="46"/>
        <source>Toggle fullscreen</source>
        <translation>切換全屏</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="47"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="48"/>
        <source>Replace</source>
        <translation>替換</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="49"/>
        <source>Go to line</source>
        <translation>跳到行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="50"/>
        <source>Save cursor position</source>
        <translation>保存光標位置</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="51"/>
        <source>Reset cursor position</source>
        <translation>跳轉到保存光標位置</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="52"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="53"/>
        <source>Display shortcuts</source>
        <translation>顯示快捷鍵</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="54"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="55"/>
        <source>Editor</source>
        <translation>編輯</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="56"/>
        <source>Increase indent</source>
        <translation>增加縮進</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="57"/>
        <source>Decrease indent</source>
        <translation>減少縮進</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="58"/>
        <source>Forward character</source>
        <translation>右移一個字符</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="59"/>
        <source>Backward character</source>
        <translation>左移一個字符</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="60"/>
        <source>Forward word</source>
        <translation>右移一個詞</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="61"/>
        <source>Backward word</source>
        <translation>左移一個詞</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="62"/>
        <source>Next line</source>
        <translation>下一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="63"/>
        <source>Previous line</source>
        <translation>上一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="64"/>
        <source>New line</source>
        <translation>換行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="65"/>
        <source>New line above</source>
        <translation>向上插入一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="66"/>
        <source>New line below</source>
        <translation>向下插入一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="67"/>
        <source>Duplicate line</source>
        <translation>複製並黏貼當前行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="68"/>
        <source>Delete to end of line</source>
        <translation>刪除到行尾</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="69"/>
        <source>Delete current line</source>
        <translation>刪除當前行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="70"/>
        <source>Swap line up</source>
        <translation>上移一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="71"/>
        <source>Swap line down</source>
        <translation>下移一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="72"/>
        <source>Scroll up one line</source>
        <translation>向上滾動一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="73"/>
        <source>Scroll down one line</source>
        <translation>向下滾動一行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="74"/>
        <source>Page up</source>
        <translation>向上滾動一頁</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="75"/>
        <source>Page down</source>
        <translation>向下滾動一頁</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="76"/>
        <source>Move to end of line</source>
        <translation>移動到行尾</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="77"/>
        <source>Move to start of line</source>
        <translation>移動到行頭</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="78"/>
        <source>Move to end of text</source>
        <translation>移動到文本結尾</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="79"/>
        <source>Move to start of text</source>
        <translation>移動到文本開頭</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="80"/>
        <source>Move to line indentation</source>
        <translation>移動到行縮進</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="81"/>
        <source>Upper case</source>
        <translation>轉換為大寫</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="82"/>
        <source>Lower case</source>
        <translation>轉換為小寫</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="83"/>
        <source>Capitalize</source>
        <translation>首字母大寫</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="84"/>
        <source>Delete backward word</source>
        <translation>向左刪除一個詞</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="85"/>
        <source>Delete forward word</source>
        <translation>向右刪除一個詞</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="86"/>
        <source>Forward over a pair</source>
        <translation>向右匹配</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="87"/>
        <source>Backward over a pair</source>
        <translation>向左匹配</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="88"/>
        <source>Select all</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="89"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="90"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="91"/>
        <source>Paste</source>
        <translation>黏貼</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="92"/>
        <source>Transpose character</source>
        <translation>調換字符</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="93"/>
        <source>Mark</source>
        <translation>設置標記</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="94"/>
        <source>Unmark</source>
        <translation>取消標記</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="95"/>
        <source>Copy line</source>
        <translation>複製行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="96"/>
        <source>Cut line</source>
        <translation>剪切行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="97"/>
        <source>Merge lines</source>
        <translation>合併行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="98"/>
        <source>Read-Only mode</source>
        <translation>切換到只讀模式</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="99"/>
        <source>Add comment</source>
        <translation>添加注釋</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="100"/>
        <source>Remove comment</source>
        <translation>取消注釋</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="101"/>
        <source>Undo</source>
        <translation>撤銷</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="102"/>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="103"/>
        <source>Add/Remove bookmark</source>
        <translation>添加/清除書籤</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="104"/>
        <source>Move to previous bookmark</source>
        <translation>跳轉到上一個書籤</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="105"/>
        <source>Move to next bookmark</source>
        <translation>跳轉到下一個書籤</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="106"/>
        <source>Advanced</source>
        <translation>高級設置</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="108"/>
        <source>Window size</source>
        <translation>窗口狀態</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="109"/>
        <source>Tab width</source>
        <translation>Tab字符寬度</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="111"/>
        <source>Word wrap</source>
        <translation>自動換行</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="112"/>
        <source>Code folding flag</source>
        <translation>顯示代碼摺疊標誌</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="113"/>
        <source>Show line numbers</source>
        <translation>顯示行號</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="114"/>
        <source>Show bookmarks icon</source>
        <translation>顯示書籤圖標</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="115"/>
        <source>Show whitespaces and tabs</source>
        <translation>顯示空白字符/制表符</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="116"/>
        <source>Highlight current line</source>
        <translation>當前行高亮</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="117"/>
        <source>Color mark</source>
        <translation>顏色標記</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="120"/>
        <source>Unicode</source>
        <translation>Unicode</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="121"/>
        <source>WesternEuropean</source>
        <translation>西歐語系</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="122"/>
        <source>CentralEuropean</source>
        <translation>中歐語系</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="123"/>
        <source>Baltic</source>
        <translation>波羅的海語言</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="124"/>
        <source>Cyrillic</source>
        <translation>西里爾文</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="125"/>
        <source>Arabic</source>
        <translation>阿拉伯語</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="130"/>
        <source>Celtic</source>
        <translation>凱爾特語</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="131"/>
        <source>SouthEasternEuropean</source>
        <translation>東南歐語系</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="126"/>
        <source>Greek</source>
        <translation>希臘語</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="127"/>
        <source>Hebrew</source>
        <translation>希伯來語</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="132"/>
        <source>ChineseSimplified</source>
        <translation>簡體中文</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="133"/>
        <source>ChineseTraditional</source>
        <translation>繁體中文</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="134"/>
        <source>Japanese</source>
        <translation>日語</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="135"/>
        <source>Korean</source>
        <translation>韓語</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="129"/>
        <source>Thai</source>
        <translation>泰語</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="128"/>
        <source>Turkish</source>
        <translation>土耳其語</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="136"/>
        <source>Vietnamese</source>
        <translation>越南語</translation>
    </message>
    <message>
        <location filename="../src/startmanager.cpp" line="762"/>
        <source>File not saved</source>
        <translation>文件未保存</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="974"/>
        <location filename="../src/widgets/window.cpp" line="1065"/>
        <location filename="../src/widgets/window.cpp" line="1080"/>
        <source>Line Endings</source>
        <translation>換行符</translation>
    </message>
</context>
<context>
    <name>ReplaceBar</name>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="39"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="43"/>
        <source>Replace With</source>
        <translation>替換為</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="47"/>
        <source>Replace</source>
        <translation>替換</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="50"/>
        <source>Skip</source>
        <translation>跳過</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="53"/>
        <source>Replace Rest</source>
        <translation>剩餘替換</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="56"/>
        <source>Replace All</source>
        <translation>全部替換</translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="../third/libiconv-1.16/src/iconv.c" line="103"/>
        <source/>
        <comment>The first line of the short usage message.</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/common/settings.cpp" line="91"/>
        <source>Standard</source>
        <translation>標準</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="91"/>
        <source>Customize</source>
        <translation>自定義</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Normal</source>
        <translation>正常窗口</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Maximum</source>
        <translation>最大化</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="292"/>
        <source>This shortcut conflicts with system shortcut %1</source>
        <translation>此快捷鍵與系統快捷鍵%1衝突</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="294"/>
        <source>This shortcut conflicts with %1, click on Replace to make this shortcut effective immediately</source>
        <translation>此快捷鍵與%1衝突，點擊替換使這個快捷鍵立即生效</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="410"/>
        <location filename="../src/common/settings.cpp" line="418"/>
        <source>The shortcut %1 is invalid, please set another one.</source>
        <translation>%1為無效快捷鍵，請重新設置</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="445"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="446"/>
        <source>Replace</source>
        <translation>替換</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="448"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>StartManager</name>
    <message>
        <location filename="../src/startmanager.cpp" line="340"/>
        <source>Untitled %1</source>
        <translation>未命名文檔%1</translation>
    </message>
</context>
<context>
    <name>Tabbar</name>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="515"/>
        <source>Close tab</source>
        <translation>關閉標籤頁</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="516"/>
        <source>Close other tabs</source>
        <translation>關閉其他標籤頁</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="517"/>
        <source>More options</source>
        <translation>更多關閉方式</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="518"/>
        <source>Close tabs to the left</source>
        <translation>關閉左側所有標籤頁</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="519"/>
        <source>Close tabs to the right</source>
        <translation>關閉右側所有標籤頁</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="520"/>
        <source>Close unmodified tabs</source>
        <translation>關閉所有未修改標籤頁</translation>
    </message>
</context>
<context>
    <name>TextEdit</name>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="235"/>
        <source>Undo</source>
        <translation>撤銷</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="236"/>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="237"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="238"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="239"/>
        <source>Paste</source>
        <translation>黏貼</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="240"/>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="241"/>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="242"/>
        <location filename="../src/widgets/window.cpp" line="361"/>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="243"/>
        <location filename="../src/widgets/window.cpp" line="362"/>
        <source>Replace</source>
        <translation>替換</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="244"/>
        <source>Go to Line</source>
        <translation>跳到行</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="245"/>
        <source>Turn on Read-Only mode</source>
        <translation>開啟只讀模式</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="246"/>
        <source>Turn off Read-Only mode</source>
        <translation>關閉只讀模式</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="247"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="248"/>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="249"/>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="250"/>
        <location filename="../src/editor/dtextedit.cpp" line="302"/>
        <source>Add Comment</source>
        <translation>添加注釋</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="251"/>
        <source>Text to Speech</source>
        <translation>語音朗讀</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="252"/>
        <source>Stop reading</source>
        <translation>停止朗讀</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="253"/>
        <source>Speech to Text</source>
        <translation>語音聽寫</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="254"/>
        <source>Translate</source>
        <translation>文本翻譯</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="255"/>
        <source>Column Mode</source>
        <translation>列編輯模式</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="256"/>
        <source>Add bookmark</source>
        <translation>添加書籤</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="257"/>
        <source>Remove Bookmark</source>
        <translation>清除書籤</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="258"/>
        <source>Previous bookmark</source>
        <translation>上一個書籤</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="259"/>
        <source>Next bookmark</source>
        <translation>下一個書籤</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="260"/>
        <source>Remove All Bookmarks</source>
        <translation>清除所有書籤</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="261"/>
        <source>Fold All</source>
        <translation>摺疊所有層次</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="262"/>
        <source>Fold Current Level</source>
        <translation>摺疊當前層次</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="263"/>
        <source>Unfold All</source>
        <translation>展開所有層次</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="264"/>
        <source>Unfold Current Level</source>
        <translation>展開當前層次</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="269"/>
        <source>Color Mark</source>
        <translation>顏色標記</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="273"/>
        <source>Clear All Marks</source>
        <translation>清除所有標記</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="274"/>
        <source>Clear Last Mark</source>
        <translation>清除上次標記</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="283"/>
        <source>Mark</source>
        <translation>設置標記</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="295"/>
        <source>Mark All</source>
        <translation>標記所有</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="303"/>
        <source>Remove Comment</source>
        <translation>取消注釋</translation>
    </message>
    <message>
        <source>Failed to paste text: it is too large</source>
        <translation type="vanished">文本內容過大，黏貼失敗</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2581"/>
        <source>Copy failed: not enough memory</source>
        <translation>內存不足，複製失敗</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2665"/>
        <source>Press ALT and click lines to edit in column mode</source>
        <translation>請使用ALT+鼠標點選切換列編輯模式</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="346"/>
        <source>Change Case</source>
        <translation>切換大小寫</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="347"/>
        <source>Upper Case</source>
        <translation>大寫</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="348"/>
        <source>Lower Case</source>
        <translation>小寫</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="349"/>
        <source>Capitalize</source>
        <translation>首字母大寫</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="64"/>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1184"/>
        <source>Selected line(s) copied</source>
        <translation>已複製選中行到剪貼板</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1190"/>
        <source>Current line copied</source>
        <translation>已複製當前行到剪貼板</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1210"/>
        <source>Selected line(s) clipped</source>
        <translation>已剪切選中行到剪貼板</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1222"/>
        <source>Current line clipped</source>
        <translation>已剪切當前行到剪貼板</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2591"/>
        <source>Paste failed: not enough memory</source>
        <translation>內存不足，黏貼失敗</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3439"/>
        <source>Read-Only mode is off</source>
        <translation>只讀模式已關閉</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3446"/>
        <location filename="../src/editor/dtextedit.cpp" line="3465"/>
        <location filename="../src/editor/dtextedit.cpp" line="6150"/>
        <source>Read-Only mode is on</source>
        <translation>只讀模式已開啟</translation>
    </message>
</context>
<context>
    <name>WarningNotices</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="36"/>
        <source>Reload</source>
        <translation>重新載入</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="38"/>
        <location filename="../src/widgets/window.cpp" line="357"/>
        <source>Save as</source>
        <translation>另存為</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="353"/>
        <source>New window</source>
        <translation>新窗口</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="354"/>
        <source>New tab</source>
        <translation>新標籤頁</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="355"/>
        <source>Open file</source>
        <translation>打開文件</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="356"/>
        <location filename="../src/widgets/window.cpp" line="2217"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="358"/>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="359"/>
        <source>Switch theme</source>
        <translation>切換主題</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="360"/>
        <location filename="../src/widgets/window.cpp" line="1542"/>
        <source>Settings</source>
        <translation>設置</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="471"/>
        <location filename="../src/widgets/window.cpp" line="2468"/>
        <source>Read-Only</source>
        <translation>只讀</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="487"/>
        <source>You do not have permission to open %1</source>
        <translation>您沒有權限打開%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="522"/>
        <source>Invalid file: %1</source>
        <translation>無效文件：%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="602"/>
        <location filename="../src/widgets/window.cpp" line="644"/>
        <source>Do you want to save this file?</source>
        <translation>您是否要保存此文件？</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="894"/>
        <source>You do not have permission to save %1</source>
        <translation>您沒有權限保存%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="918"/>
        <source>Saved successfully</source>
        <translation>文件已保存</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="954"/>
        <location filename="../src/widgets/window.cpp" line="1021"/>
        <location filename="../src/widgets/window.cpp" line="1062"/>
        <source>Save File</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1023"/>
        <source>Encoding</source>
        <translation>編碼</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1211"/>
        <source>Read-Only mode is on</source>
        <translation>只讀模式已開啟</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1441"/>
        <source>Current location remembered</source>
        <translation>已記住當前位置</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1492"/>
        <source>Ctrl+&apos;=&apos;</source>
        <translation>Ctrl+&apos;=&apos;</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1495"/>
        <source>Ctrl+&apos;-&apos;</source>
        <translation>Ctrl+&apos;-&apos;</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1524"/>
        <source>Editor</source>
        <translation>編輯</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1890"/>
        <source>Untitled %1</source>
        <translation>未命名文檔%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2215"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2216"/>
        <source>Discard</source>
        <translation>不保存</translation>
    </message>
</context>
</TS>